@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 tests.test_finalizers
 ~~~~~~~~~~~~~~~~~~~~~
@@ -7,14 +5,13 @@ tests.test_finalizers
 """
 
 from yaspin import yaspin
-from yaspin.compat import builtin_str
 
 
 def test_freeze(final_text):
     sp = yaspin()
     sp._freeze(final_text)
 
-    assert isinstance(sp._last_frame, builtin_str)
+    assert isinstance(sp._last_frame, str)
     assert sp._last_frame[-1] == "\n"
 
 
@@ -22,7 +19,7 @@ def test_ok(final_text):
     sp = yaspin()
     sp.ok(final_text)
 
-    assert isinstance(sp._last_frame, builtin_str)
+    assert isinstance(sp._last_frame, str)
     assert sp._last_frame[-1] == "\n"
 
 
@@ -36,7 +33,7 @@ def test_fail(final_text):
     sp = yaspin()
     sp.fail(final_text)
 
-    assert isinstance(sp._last_frame, builtin_str)
+    assert isinstance(sp._last_frame, str)
     assert sp._last_frame[-1] == "\n"
 
 
